import { sendMessage } from '../bot/utils/messaging.ts'
import { formatUserMention } from '../utils/userUtils';
import { Task } from '../models/task';

export function notifyTaskCreation(task: Task) {
  const creatorMention = formatUserMention(task.createdBy);
  const assigneeMention = task.assignedTo ? formatUserMention(task.assignedTo) : 'ninguno';
  
  // Notify creator
  let message = `✅ Tarea creada:\nID: ${task.id}\nDescripción: ${task.description}`;
  if (task.assignedTo) {
    message += `\nAsignada a: ${assigneeMention}`;
  }
  if (task.dueDate) {
    message += `\nFecha límite: ${task.dueDate}`;
  }
  sendMessage(task.createdBy, message);

  // Notify assignee if different from creator
  if (task.assignedTo && task.assignedTo !== task.createdBy) {
    const assigneeMessage = `📝 ${creatorMention} te ha asignado una nueva tarea:\n` +
      `ID: ${task.id}\nDescripción: ${task.description}` +
      (task.dueDate ? `\nFecha límite: ${task.dueDate}` : '');
    sendMessage(task.assignedTo, assigneeMessage, [task.assignedTo.split('@')[0]]);
  }
}

export function notifyTaskAssignment(task: Task, assignedBy: string) {
  const assignerMention = formatUserMention(assignedBy);
  const assigneeMention = formatUserMention(task.assignedTo);

  // Notify assigner
  sendMessage(assignedBy, `✅ Tarea ${task.id} asignada a ${assigneeMention}`);

  // Notify assignee
  const assigneeMessage = `📝 ${assignerMention} te ha asignado la tarea:\n` +
    `ID: ${task.id}\nDescripción: ${task.description}` +
    (task.dueDate ? `\nFecha límite: ${task.dueDate}` : '');
  sendMessage(task.assignedTo, assigneeMessage);
}

export function notifyTaskCompletion(task: Task, completedBy: string) {
  const completerMention = formatUserMention(completedBy);

  // Notify completer
  sendMessage(completedBy, `✅ Tarea completada:\nID: ${task.id}\nDescripción: ${task.description}`);

  // Notify creator if different from completer
  if (task.createdBy && task.createdBy !== completedBy) {
    const creatorMessage = `✅ ${completerMention} ha completado la tarea:\n` +
      `ID: ${task.id}\nDescripción: ${task.description}`;
    sendMessage(task.createdBy, creatorMessage);
  }
}
